@@ -141,6 +141,8 @@ class DataFrame(dict):
         return super().__delattr__(name)
 
     def __delitem__(self, key):
+        # Note that this is not called for some methods,
+        # at least pop, popitem and clear.
         if self[key] is self.COLUMN_PLACEHOLDER:
             super().__delattr__(key)
         return super().__delitem__(key)
@@ -161,7 +163,7 @@ class DataFrame(dict):
         value = super().__getattribute__(name)
         if name == "COLUMN_PLACEHOLDER":
             return value
-        if value is self.COLUMN_PLACEHOLDER:
+        if value is self.COLUMN_PLACEHOLDER and name in self:
             return self[name]
         return value
 
@@ -282,6 +284,9 @@ class DataFrame(dict):
         if len(set(nrows)) == 1: return
         raise ValueError(f"Bad dimensions: {nrows!r}")
 
+    def clear(self):
+        return self._new()
+
     @property
     def colnames(self):
         """
@@ -700,6 +705,18 @@ class DataFrame(dict):
     def _parse_rows_from_integer(self, rows):
         return Vector.fast(rows, int)
 
+    def pop(self, key, *args, **kwargs):
+        value = super().pop(key, *args, **kwargs)
+        if hasattr(self, key):
+            super().__delattr__(key)
+        return value
+
+    def popitem(self):
+        key, value = super().popitem()
+        if hasattr(self, key):
+            super().__delattr__(key)
+        return key, value
+
     def print_(self, *, max_rows=None, max_width=None, truncate_width=None):
         """
         Print data frame to ``sys.stdout``.
@@ -922,6 +939,27 @@ class DataFrame(dict):
         for colname in (self.colnames[x] for x in cols):
             yield colname, self[colname][rows].copy()
 
+    @deco.new_from_generator
+    def slice_off(self, rows=None, cols=None):
+        """
+        Return a row-wise and/or column-wise negative subset of data frame.
+
+        Both `rows` and `cols` should be integer vectors correspoding to the
+        indices of the rows or columns to drop.
+
+        >>> data = di.read_csv("data/listings.csv")
+        >>> data.slice_off(rows=[0, 1, 2])
+        >>> data.slice_off(cols=[0, 1, 2])
+        >>> data.slice_off(rows=[0, 1, 2], cols=[0, 1, 2])
+        """
+        rows = [] if rows is None else rows
+        cols = [] if cols is None else cols
+        rows = self._parse_rows_from_integer(rows)
+        cols = self._parse_cols_from_integer(cols)
+        for i, colname in enumerate(self.colnames):
+            if i in cols: continue
+            yield colname, np.delete(self[colname], rows)
+
     @deco.new_from_generator
     def sort(self, **colname_dir_pairs):
         """
